#!/bin/sh

echo "+++++ Checking current user rights..."

if [ "$(id -u root)" = "$(id -u)" ] ; then
    :
else
    echo "ERROR: The current user id is not root (`id|awk '{print $1}'`)."
    exit 1
fi
echo


USAGE="usage: $0 [-a [x86|x86_64|all]]"
# Initialize args
ARCH=all

set -- `getopt ha: "$@"`
[ $# -lt 1 ] && exit 1  # getopt failed
while [ $# -gt 0 ]
do
    case "$1" in
        -a)    ARCH="$2"; shift;;
        --)    shift; break;;
        -*|-h)
               echo >&2 \
               $USAGE
               exit 1;;
        *)     
               echo >&2 \
               $USAGE
               exit 1;;
    esac
    shift
done
case $ARCH in
    all|x86|x86_64) ;;
    *)    echo >&2 $USAGE
          exit 1;;
esac

X86=0; X86_64=0
if [ "$ARCH" = "all" ] ; then
    X86=1; X86_64=1
else
    if [ "$ARCH" = "x86" ] ; then
        X86=1
    fi
    if [ "$ARCH" = "x86_64" ] ; then
        X86_64=1
    fi
fi


if [ "X$PVSW_ROOT" = "X" ] ; then
    PVSW_ROOT=/usr/local/psql
fi
PATH=$PVSW_ROOT/bin:$PATH
if [ $(uname -s) = "Darwin" ]
then
    DYLD_LIBRARY_PATH=$PVSW_ROOT/bin:$PVSW_ROOT/lib:$PVSW_ROOT/lib64:$DYLD_LIBRARY_PATH
    export DYLD_LIBRARY_PATH
else
    LD_LIBRARY_PATH=$PVSW_ROOT/bin:$PVSW_ROOT/lib:$PVSW_ROOT/lib64:$LD_LIBRARY_PATH
fi


echo "+++++ Removing PSQL directories..."

if [ "$ARCH" = "all" ] ; then
    HOMEDIR=`grep "^psql:" /etc/passwd | cut -d: -f6`
    rm -f $HOMEDIR/.cshrc
    rm -f $HOMEDIR/.bash_profile
    rm -f $HOMEDIR/.bash_history
    rm -f $HOMEDIR/.bashrc
    rm -f  $PVSW_ROOT/LICENSE
    rm -f  $PVSW_ROOT/PSQL_Client_Third_Party_Notice
    rm -Rf $PVSW_ROOT/bin
    rm -Rf $PVSW_ROOT/jre
    rm -Rf $PVSW_ROOT/lib
    rm -Rf $PVSW_ROOT/lib64
    rm -Rf $PVSW_ROOT/man
    rm -Rf $PVSW_ROOT/docs
    rm -Rf $PVSW_ROOT/log
fi
if [ "$ARCH" = "x86" ] ; then
    rm -Rf $PVSW_ROOT/bin/configuration
    rm -Rf $PVSW_ROOT/bin/plugins
    rm -Rf $PVSW_ROOT/jre
    rm -Rf $PVSW_ROOT/lib
    rm -Rf $PVSW_ROOT/man
    # Don't delete any files ending with "64".
    for f in `ls $PVSW_ROOT/bin | sed '/64$/d'` ; do
        rm -f $PVSW_ROOT/bin/$f
    done
fi
if [ "$ARCH" = "x86_64" ] ; then
    rm -Rf $PVSW_ROOT/lib64
    rm -Rf $PVSW_ROOT/bin/*64
fi


echo
echo "Uninstall has successfully completed."
echo



















